"""
A color palette to make coloring consistent project wide.
"""
from bokeh.colors import named

light_curve_colors = [named.mediumblue, named.firebrick, named.green, named.darkorange]
